@@ -1,9 +1,7 @@
 import json
 import os
-import pickle
 import re
 import sys
-from datetime import datetime
 
 import numpy as np
 import pandas as pd
@@ -147,16 +145,10 @@ class Features:
         self.bad_words
 
         try:
-            file_name = "utils/dataframes/" + str(
-                int(datetime.timestamp(datetime.now()))
+            out_dict = send_to_model(
+                data={"value": input_txt},
+                ms_models_path=URL_MS_MODELOS + "/models_reg/features/pos_tags",
             )
-            file_to_send = BASE_DIR + "/" + file_name
-            pickle.dump(self.input_txt.lower(), open(file_to_send, "wb"))
-            file_send = {"model_json": open(file_to_send, "rb")}
-            ms_models = URL_MS_MODELOS + "/features/pos_tags"
-            doc_response = requests.post(url=ms_models, files=file_send)
-            delete_file_dataframe(file_to_send, file_send)
-            out_dict = pickle.loads(doc_response.content)
         except Exception as e:
             print(e)
             error_1 = sys.exc_info()[0]
@@ -182,7 +174,7 @@ class Polarity(object):
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            return ""
+            raise e
         input_ids_b = encoded_dict["input_ids"]
         attention_masks_b = encoded_dict["attention_mask"]
 
@@ -197,7 +189,7 @@ class Polarity(object):
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            return ""
+            raise e
 
         sentiment = list(out.argmax(1).numpy())
 
@@ -320,7 +312,7 @@ class Polarity(object):
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            return ""
+            raise e
 
     def polarity_only(self, df_text, column_text="message"):
         """
@@ -350,7 +342,7 @@ class Polarity(object):
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
-            return ""
+            raise e
 
 
 class STTM(object):
@@ -394,6 +386,7 @@ class STTM(object):
             DataFrame with the 'sttm_group' column
 
         """
+
         try:
             model_name = "sttm"
             model_type = "sttm_model"
@@ -404,20 +397,47 @@ class STTM(object):
             print(e)
             error_1 = sys.exc_info()[0]
             print(ERR_SYS + str(error_1))
+            raise e
         return self.df_data
 
 
-def send_to_model(value, ms_models):
-    values = {"value": value}
-    response = requests.post(url=ms_models, data=json.dumps(values))
-    return response.text
+def send_to_model(data, ms_models_path, ensure_ascii=True):
+    """
+    Auxiliar function used to send data to models microservice
+
+    Parameters
+    ----------
+    data :
+        Request body
+    ms_models : [type]
+        Path of models microservice
+    """
+
+    response = requests.post(url=ms_models_path, data=json.dumps(data))
+
+    if response.ok:
+        return response.json()
+    else:
+        raise RuntimeError(f"Models microservice error {response.status_code}")
 
 
 def df_to_formatted(df, url_model, model_name, model_type):
-    ms_models = url_model + "_reg/" + model_name + "/" + model_type
-    # TODO: cambiar iterrows por .applylamdba
-    for index, row in df.iterrows():
-        row = row.copy()
-        polarity_value = send_to_model(row.processed_text, ms_models)
-        df.loc[index, "polarity"] = polarity_value
+    ms_models_path = url_model + "/models_reg/" + model_name + "/" + model_type
+
+    if model_name == "polarity":
+        df["polarity"] = df["processed_text"].apply(
+            lambda txt: send_to_model({"value": txt}, ms_models_path)
+        )
+    elif model_name == "sttm":
+
+        response = send_to_model(
+            data=df[["id", "tokenized_text"]].to_dict(orient="records"),
+            ms_models_path=ms_models_path,
+            ensure_ascii=False,
+        )
+
+        df = pd.merge(df, pd.DataFrame(response, columns=["id", "sttm_group"]), on="id")
+    else:
+        raise NotImplementedError()
+
     return df
